@@ -6,33 +6,43 @@ test_that("Test figure caption basic functionality",{
   expect_equivalent(figCapNoNext(), 1)
   expect_match(figCapNo("a", roman = FALSE, sprintf_str = "%s: %s"),
                "1+: a")
-  
+
   expect_match(figCapNo("a", roman = FALSE, sprintf_str = "%s: %s"),
                "2: a")
-  
+
   expect_match(figCapNo("a", roman = TRUE, sprintf_str = "%s: %s"),
                "III: a")
 
   options(fig_caption_no = NULL)
   expect_match(figCapNo("a", roman = TRUE, sprintf_str = "%s: %s"),
                "I: a")
-  
+
   expect_error(figCapNo())
+
+  options(fig_caption_no = FALSE)
+  expect_error(figCapNoNext())
+
+  expect_equal(figCapNo("test"), "test")
+
+  options(fig_caption_no = TRUE)
+  expect_equal(figCapNoNext(), 1)
+  expect_equal(figCapNo("a", roman = FALSE, sprintf_str = "%s: %s"),
+               "1: a")
+
 })
 
 test_that("Test figure caption options",{
   options(fig_caption_no = 2)
   expect_equivalent(figCapNoLast(), 2)
   expect_equivalent(figCapNoNext(), 3)
-  
+
   options(fig_caption_no_roman = TRUE)
   expect_equivalent(figCapNoLast(), "II")
   expect_equivalent(figCapNoNext(), "III")
 
   options(fig_caption_no = 10)
   expect_equivalent(figCapNo("test"), "Fig. XI: test")
-  
+
   options(fig_caption_no_roman = FALSE)
   expect_equivalent(figCapNo("test"), "Fig. 12: test")
 })
-  
\ No newline at end of file
